Lines Matching refs:HostDeviceReturnTy
22 struct HostDeviceReturnTy {}; struct
27 typedef HostDeviceReturnTy (*HostDeviceFnPtr)();
346 __host__ __device__ HostDeviceReturnTy template_vs_hd_function(float arg) { in template_vs_hd_function()
347 return HostDeviceReturnTy(); in template_vs_hd_function()
352 typedef HostDeviceReturnTy ExpectedReturnTy; in test_host_device_calls_hd_template()
356 HostDeviceReturnTy ret1 = template_vs_hd_function(1.0f); in test_host_device_calls_hd_template()
362 HostDeviceReturnTy ret1 = template_vs_hd_function(1.0f); in test_host_calls_hd_template()
367 HostDeviceReturnTy ret1 = template_vs_hd_function(1.0f); in test_device_calls_hd_template()
370 HostDeviceReturnTy ret2 = template_vs_hd_function(1); in test_device_calls_hd_template()
484 HostDeviceReturnTy callee(int x);
498 HostDeviceReturnTy callee(double x);
499 inline HostDeviceReturnTy implicit_hd_caller() { in implicit_hd_caller()
512 __host__ __device__ HostDeviceReturnTy callee(int x);
514 typedef HostDeviceReturnTy ExpectedRetTy;